==> haskell-unix-compat-0.4.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
key: unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: 0c10439e716e700a12f9bc14f443845d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
include-dirs: /usr/lib/ghc-8.0.1/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.9.0.0 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.4.3.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unix-compat
version: 0.4.3.1
id: unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
key: unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
license: BSD3
maintainer: Jacob Stanley <jacob@stanley.io>
homepage: http://github.com/jystic/unix-compat
synopsis: Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.
category: System
author: Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan
exposed: True
indefinite: False
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User
abi: c3087b497fbb9a1a0b9e1db4ff794ff4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/unix-compat-0.4.3.1
hs-libraries: HSunix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
include-dirs: /usr/lib/ghc-8.2.1/site-local/unix-compat-0.4.3.1/include
includes:
    HsUnixCompat.h
depends:
    base-4.10.0.0 unix-2.7.2.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             unix-2.7.2.2=65f42a53c0d1c7bb4ba5966ba6a43504
haddock-interfaces: /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html: /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
